==> rpm-4.2.tar.gz: rpm-4.2/rpmdb/tagtbl.c <==
/*@-bounds@*/
#include "system.h"
#include <rpmlib.h>

/*@observer@*/ /*@unchecked@*/
static const struct headerTagTableEntry_s rpmTagTbl[] = {
	{ "RPMTAG_HEADERIMAGE", HEADER_IMAGE, },
	{ "RPMTAG_HEADERSIGNATURES", HEADER_SIGNATURES, },
	{ "RPMTAG_HEADERIMMUTABLE", HEADER_IMMUTABLE, },
	{ "RPMTAG_HEADERREGIONS", HEADER_REGIONS, },
	{ "RPMTAG_HEADERI18NTABLE", HEADER_I18NTABLE, },
	{ "RPMTAG_SIGSIZE", RPMTAG_SIG_BASE+1, },
	{ "RPMTAG_SIGPGP", RPMTAG_SIG_BASE+3, },
	{ "RPMTAG_SIGMD5", RPMTAG_SIG_BASE+5, },
	{ "RPMTAG_SIGGPG", RPMTAG_SIG_BASE+6, },
	{ "RPMTAG_PUBKEYS", RPMTAG_SIG_BASE+10, },
	{ "RPMTAG_DSAHEADER", RPMTAG_SIG_BASE+11, },
	{ "RPMTAG_RSAHEADER", RPMTAG_SIG_BASE+12, },
	{ "RPMTAG_SHA1HEADER", RPMTAG_SIG_BASE+13, },
	{ "RPMTAG_NAME", 1000, },
	{ "RPMTAG_VERSION", 1001, },
	{ "RPMTAG_RELEASE", 1002, },
	{ "RPMTAG_EPOCH", 1003, },
	{ "RPMTAG_SERIAL", RPMTAG_EPOCH },
	{ "RPMTAG_SUMMARY", 1004, },
	{ "RPMTAG_DESCRIPTION", 1005, },
	{ "RPMTAG_BUILDTIME", 1006, },
	{ "RPMTAG_BUILDHOST", 1007, },
	{ "RPMTAG_INSTALLTIME", 1008, },
	{ "RPMTAG_SIZE", 1009, },
	{ "RPMTAG_DISTRIBUTION", 1010, },
	{ "RPMTAG_VENDOR", 1011, },
	{ "RPMTAG_GIF", 1012, },
	{ "RPMTAG_XPM", 1013, },
	{ "RPMTAG_LICENSE", 1014, },
	{ "RPMTAG_COPYRIGHT", RPMTAG_LICENSE },
	{ "RPMTAG_PACKAGER", 1015, },
	{ "RPMTAG_GROUP", 1016, },
	{ "RPMTAG_SOURCE", 1018, },
	{ "RPMTAG_PATCH", 1019, },
	{ "RPMTAG_URL", 1020, },
	{ "RPMTAG_OS", 1021, },
	{ "RPMTAG_ARCH", 1022, },
	{ "RPMTAG_PREIN", 1023, },
	{ "RPMTAG_POSTIN", 1024, },
	{ "RPMTAG_PREUN", 1025, },
	{ "RPMTAG_POSTUN", 1026, },
	{ "RPMTAG_OLDFILENAMES", 1027, },
	{ "RPMTAG_FILESIZES", 1028, },
	{ "RPMTAG_FILESTATES", 1029, },
	{ "RPMTAG_FILEMODES", 1030, },
	{ "RPMTAG_FILERDEVS", 1033, },
	{ "RPMTAG_FILEMTIMES", 1034, },
	{ "RPMTAG_FILEMD5S", 1035, },
	{ "RPMTAG_FILELINKTOS", 1036, },
	{ "RPMTAG_FILEFLAGS", 1037, },
	{ "RPMTAG_FILEUSERNAME", 1039, },
	{ "RPMTAG_FILEGROUPNAME", 1040, },
	{ "RPMTAG_ICON", 1043, },
	{ "RPMTAG_SOURCERPM", 1044, },
	{ "RPMTAG_FILEVERIFYFLAGS", 1045, },
	{ "RPMTAG_ARCHIVESIZE", 1046, },
	{ "RPMTAG_PROVIDENAME", 1047, },
	{ "RPMTAG_PROVIDES", RPMTAG_PROVIDENAME },
	{ "RPMTAG_REQUIREFLAGS", 1048, },
	{ "RPMTAG_REQUIRENAME", 1049, },
	{ "RPMTAG_REQUIREVERSION", 1050, },
	{ "RPMTAG_CONFLICTFLAGS", 1053, },
	{ "RPMTAG_CONFLICTNAME", 1054, },
	{ "RPMTAG_CONFLICTVERSION", 1055, },
	{ "RPMTAG_EXCLUDEARCH", 1059, },
	{ "RPMTAG_EXCLUDEOS", 1060, },
	{ "RPMTAG_EXCLUSIVEARCH", 1061, },
	{ "RPMTAG_EXCLUSIVEOS", 1062, },
	{ "RPMTAG_RPMVERSION", 1064, },
	{ "RPMTAG_TRIGGERSCRIPTS", 1065, },
	{ "RPMTAG_TRIGGERNAME", 1066, },
	{ "RPMTAG_TRIGGERVERSION", 1067, },
	{ "RPMTAG_TRIGGERFLAGS", 1068, },
	{ "RPMTAG_TRIGGERINDEX", 1069, },
	{ "RPMTAG_VERIFYSCRIPT", 1079, },
	{ "RPMTAG_CHANGELOGTIME", 1080, },
	{ "RPMTAG_CHANGELOGNAME", 1081, },
	{ "RPMTAG_CHANGELOGTEXT", 1082, },
	{ "RPMTAG_PREINPROG", 1085, },
	{ "RPMTAG_POSTINPROG", 1086, },
	{ "RPMTAG_PREUNPROG", 1087, },
	{ "RPMTAG_POSTUNPROG", 1088, },
	{ "RPMTAG_BUILDARCHS", 1089, },
	{ "RPMTAG_OBSOLETENAME", 1090, },
	{ "RPMTAG_OBSOLETES", RPMTAG_OBSOLETENAME },
	{ "RPMTAG_VERIFYSCRIPTPROG", 1091, },
	{ "RPMTAG_TRIGGERSCRIPTPROG", 1092, },
	{ "RPMTAG_COOKIE", 1094, },
	{ "RPMTAG_FILEDEVICES", 1095, },
	{ "RPMTAG_FILEINODES", 1096, },
	{ "RPMTAG_FILELANGS", 1097, },
	{ "RPMTAG_PREFIXES", 1098, },
	{ "RPMTAG_INSTPREFIXES", 1099, },
	{ "RPMTAG_SOURCEPACKAGE", 1106, },
	{ "RPMTAG_PROVIDEFLAGS", 1112, },
	{ "RPMTAG_PROVIDEVERSION", 1113, },
	{ "RPMTAG_OBSOLETEFLAGS", 1114, },
	{ "RPMTAG_OBSOLETEVERSION", 1115, },
	{ "RPMTAG_DIRINDEXES", 1116, },
	{ "RPMTAG_BASENAMES", 1117, },
	{ "RPMTAG_DIRNAMES", 1118, },
	{ "RPMTAG_OPTFLAGS", 1122, },
	{ "RPMTAG_DISTURL", 1123, },
	{ "RPMTAG_PAYLOADFORMAT", 1124, },
	{ "RPMTAG_PAYLOADCOMPRESSOR", 1125, },
	{ "RPMTAG_PAYLOADFLAGS", 1126, },
	{ "RPMTAG_INSTALLCOLOR", 1127, },
	{ "RPMTAG_INSTALLTID", 1128, },
	{ "RPMTAG_REMOVETID", 1129, },
	{ "RPMTAG_RHNPLATFORM", 1131, },
	{ "RPMTAG_PLATFORM", 1132, },
	{ "RPMTAG_PATCHESNAME", 1133, },
	{ "RPMTAG_PATCHESFLAGS", 1134, },
	{ "RPMTAG_PATCHESVERSION", 1135, },
	{ "RPMTAG_CACHECTIME", 1136, },
	{ "RPMTAG_CACHEPKGPATH", 1137, },
	{ "RPMTAG_CACHEPKGSIZE", 1138, },
	{ "RPMTAG_CACHEPKGMTIME", 1139, },
	{ "RPMTAG_FILECOLORS", 1140, },
	{ "RPMTAG_FILECLASS", 1141, },
	{ "RPMTAG_CLASSDICT", 1142, },
	{ "RPMTAG_FILEDEPENDSX", 1143, },
	{ "RPMTAG_FILEDEPENDSN", 1144, },
	{ "RPMTAG_DEPENDSDICT", 1145, },
	{ "RPMTAG_SOURCEPKGID", 1146, },
	{ NULL, 0 }
};

/*@observer@*/ /*@unchecked@*/
const struct headerTagTableEntry_s * rpmTagTable = rpmTagTbl;

/*@unchecked@*/
const int rpmTagTableSize = sizeof(rpmTagTbl) / sizeof(rpmTagTbl[0]) - 1;
/*@=bounds@*/

==> rpm-4.3.3.tar.gz: rpm-4.3.3/rpmdb/tagtbl.c <==
/*@-bounds@*/
#include "system.h"
#include <rpmlib.h>

/*@observer@*/ /*@unchecked@*/
static const struct headerTagTableEntry_s rpmTagTbl[] = {
	{ "RPMTAG_HEADERIMAGE", HEADER_IMAGE, },
	{ "RPMTAG_HEADERSIGNATURES", HEADER_SIGNATURES, },
	{ "RPMTAG_HEADERIMMUTABLE", HEADER_IMMUTABLE, },
	{ "RPMTAG_HEADERREGIONS", HEADER_REGIONS, },
	{ "RPMTAG_HEADERI18NTABLE", HEADER_I18NTABLE, },
	{ "RPMTAG_SIGSIZE", RPMTAG_SIG_BASE+1, },
	{ "RPMTAG_SIGPGP", RPMTAG_SIG_BASE+3, },
	{ "RPMTAG_SIGMD5", RPMTAG_SIG_BASE+5, },
	{ "RPMTAG_PKGID", RPMTAG_SIGMD5 },
	{ "RPMTAG_SIGGPG", RPMTAG_SIG_BASE+6, },
	{ "RPMTAG_PUBKEYS", RPMTAG_SIG_BASE+10, },
	{ "RPMTAG_DSAHEADER", RPMTAG_SIG_BASE+11, },
	{ "RPMTAG_RSAHEADER", RPMTAG_SIG_BASE+12, },
	{ "RPMTAG_SHA1HEADER", RPMTAG_SIG_BASE+13, },
	{ "RPMTAG_HDRID", RPMTAG_SHA1HEADER },
	{ "RPMTAG_NAME", 1000, },
	{ "RPMTAG_N", RPMTAG_NAME },
	{ "RPMTAG_VERSION", 1001, },
	{ "RPMTAG_V", RPMTAG_VERSION },
	{ "RPMTAG_RELEASE", 1002, },
	{ "RPMTAG_R", RPMTAG_RELEASE },
	{ "RPMTAG_EPOCH", 1003, },
	{ "RPMTAG_E", RPMTAG_EPOCH },
	{ "RPMTAG_SERIAL", RPMTAG_EPOCH },
	{ "RPMTAG_SUMMARY", 1004, },
	{ "RPMTAG_DESCRIPTION", 1005, },
	{ "RPMTAG_BUILDTIME", 1006, },
	{ "RPMTAG_BUILDHOST", 1007, },
	{ "RPMTAG_INSTALLTIME", 1008, },
	{ "RPMTAG_SIZE", 1009, },
	{ "RPMTAG_DISTRIBUTION", 1010, },
	{ "RPMTAG_VENDOR", 1011, },
	{ "RPMTAG_GIF", 1012, },
	{ "RPMTAG_XPM", 1013, },
	{ "RPMTAG_LICENSE", 1014, },
	{ "RPMTAG_COPYRIGHT", RPMTAG_LICENSE },
	{ "RPMTAG_PACKAGER", 1015, },
	{ "RPMTAG_GROUP", 1016, },
	{ "RPMTAG_SOURCE", 1018, },
	{ "RPMTAG_PATCH", 1019, },
	{ "RPMTAG_URL", 1020, },
	{ "RPMTAG_OS", 1021, },
	{ "RPMTAG_ARCH", 1022, },
	{ "RPMTAG_PREIN", 1023, },
	{ "RPMTAG_POSTIN", 1024, },
	{ "RPMTAG_PREUN", 1025, },
	{ "RPMTAG_POSTUN", 1026, },
	{ "RPMTAG_OLDFILENAMES", 1027, },
	{ "RPMTAG_FILESIZES", 1028, },
	{ "RPMTAG_FILESTATES", 1029, },
	{ "RPMTAG_FILEMODES", 1030, },
	{ "RPMTAG_FILERDEVS", 1033, },
	{ "RPMTAG_FILEMTIMES", 1034, },
	{ "RPMTAG_FILEMD5S", 1035, },
	{ "RPMTAG_FILELINKTOS", 1036, },
	{ "RPMTAG_FILEFLAGS", 1037, },
	{ "RPMTAG_FILEUSERNAME", 1039, },
	{ "RPMTAG_FILEGROUPNAME", 1040, },
	{ "RPMTAG_ICON", 1043, },
	{ "RPMTAG_SOURCERPM", 1044, },
	{ "RPMTAG_FILEVERIFYFLAGS", 1045, },
	{ "RPMTAG_ARCHIVESIZE", 1046, },
	{ "RPMTAG_PROVIDENAME", 1047, },
	{ "RPMTAG_PROVIDES", RPMTAG_PROVIDENAME },
	{ "RPMTAG_P", RPMTAG_PROVIDENAME },
	{ "RPMTAG_REQUIREFLAGS", 1048, },
	{ "RPMTAG_REQUIRENAME", 1049, },
	{ "RPMTAG_REQUIRES", RPMTAG_REQUIRENAME },
	{ "RPMTAG_D", RPMTAG_REQUIRENAME },
	{ "RPMTAG_REQUIREVERSION", 1050, },
	{ "RPMTAG_CONFLICTFLAGS", 1053, },
	{ "RPMTAG_CONFLICTNAME", 1054, },
	{ "RPMTAG_CONFLICTS", RPMTAG_CONFLICTNAME },
	{ "RPMTAG_C", RPMTAG_CONFLICTNAME },
	{ "RPMTAG_CONFLICTVERSION", 1055, },
	{ "RPMTAG_EXCLUDEARCH", 1059, },
	{ "RPMTAG_EXCLUDEOS", 1060, },
	{ "RPMTAG_EXCLUSIVEARCH", 1061, },
	{ "RPMTAG_EXCLUSIVEOS", 1062, },
	{ "RPMTAG_RPMVERSION", 1064, },
	{ "RPMTAG_TRIGGERSCRIPTS", 1065, },
	{ "RPMTAG_TRIGGERNAME", 1066, },
	{ "RPMTAG_TRIGGERVERSION", 1067, },
	{ "RPMTAG_TRIGGERFLAGS", 1068, },
	{ "RPMTAG_TRIGGERINDEX", 1069, },
	{ "RPMTAG_VERIFYSCRIPT", 1079, },
	{ "RPMTAG_CHANGELOGTIME", 1080, },
	{ "RPMTAG_CHANGELOGNAME", 1081, },
	{ "RPMTAG_CHANGELOGTEXT", 1082, },
	{ "RPMTAG_PREINPROG", 1085, },
	{ "RPMTAG_POSTINPROG", 1086, },
	{ "RPMTAG_PREUNPROG", 1087, },
	{ "RPMTAG_POSTUNPROG", 1088, },
	{ "RPMTAG_BUILDARCHS", 1089, },
	{ "RPMTAG_OBSOLETENAME", 1090, },
	{ "RPMTAG_OBSOLETES", RPMTAG_OBSOLETENAME },
	{ "RPMTAG_O", RPMTAG_OBSOLETENAME },
	{ "RPMTAG_VERIFYSCRIPTPROG", 1091, },
	{ "RPMTAG_TRIGGERSCRIPTPROG", 1092, },
	{ "RPMTAG_COOKIE", 1094, },
	{ "RPMTAG_FILEDEVICES", 1095, },
	{ "RPMTAG_FILEINODES", 1096, },
	{ "RPMTAG_FILELANGS", 1097, },
	{ "RPMTAG_PREFIXES", 1098, },
	{ "RPMTAG_INSTPREFIXES", 1099, },
	{ "RPMTAG_SOURCEPACKAGE", 1106, },
	{ "RPMTAG_PROVIDEFLAGS", 1112, },
	{ "RPMTAG_PROVIDEVERSION", 1113, },
	{ "RPMTAG_OBSOLETEFLAGS", 1114, },
	{ "RPMTAG_OBSOLETEVERSION", 1115, },
	{ "RPMTAG_DIRINDEXES", 1116, },
	{ "RPMTAG_BASENAMES", 1117, },
	{ "RPMTAG_DIRNAMES", 1118, },
	{ "RPMTAG_OPTFLAGS", 1122, },
	{ "RPMTAG_DISTURL", 1123, },
	{ "RPMTAG_PAYLOADFORMAT", 1124, },
	{ "RPMTAG_PAYLOADCOMPRESSOR", 1125, },
	{ "RPMTAG_PAYLOADFLAGS", 1126, },
	{ "RPMTAG_INSTALLCOLOR", 1127, },
	{ "RPMTAG_INSTALLTID", 1128, },
	{ "RPMTAG_REMOVETID", 1129, },
	{ "RPMTAG_RHNPLATFORM", 1131, },
	{ "RPMTAG_PLATFORM", 1132, },
	{ "RPMTAG_PATCHESNAME", 1133, },
	{ "RPMTAG_PATCHESFLAGS", 1134, },
	{ "RPMTAG_PATCHESVERSION", 1135, },
	{ "RPMTAG_CACHECTIME", 1136, },
	{ "RPMTAG_CACHEPKGPATH", 1137, },
	{ "RPMTAG_CACHEPKGSIZE", 1138, },
	{ "RPMTAG_CACHEPKGMTIME", 1139, },
	{ "RPMTAG_FILECOLORS", 1140, },
	{ "RPMTAG_FILECLASS", 1141, },
	{ "RPMTAG_CLASSDICT", 1142, },
	{ "RPMTAG_FILEDEPENDSX", 1143, },
	{ "RPMTAG_FILEDEPENDSN", 1144, },
	{ "RPMTAG_DEPENDSDICT", 1145, },
	{ "RPMTAG_SOURCEPKGID", 1146, },
	{ "RPMTAG_FILECONTEXTS", 1147, },
	{ "RPMTAG_FSCONTEXTS", 1148, },
	{ "RPMTAG_RECONTEXTS", 1149, },
	{ "RPMTAG_POLICIES", 1150, },
	{ NULL, 0 }
};

/*@observer@*/ /*@unchecked@*/
const struct headerTagTableEntry_s * rpmTagTable = rpmTagTbl;

/*@unchecked@*/
const int rpmTagTableSize = sizeof(rpmTagTbl) / sizeof(rpmTagTbl[0]) - 1;
/*@=bounds@*/
